#include <stdio.h>
#include <math.h>

const long MAX_VECTORS_COUNT = 100; //100
const double PI = 3.14159265358;

long _sign(long x)
{
	return (x < 0) ? -1 : ((x > 0) ? 1 : 0);
}

double _ToDegrees(double angle)
{
	return angle*180/PI;
}

template<class T> struct Vector2D
{
	Vector2D(T initX=0, T initY=0) : x(initX), y(initY) {}
	
	Vector2D operator-(const Vector2D& toSub)
	{
		return Vector2D(x-toSub.x, y-toSub.y);
	}
	T operator%(const Vector2D& toMult)
	{
		return x*toMult.y - y*toMult.x;
	}
	T operator*(const Vector2D& toMult)
	{
		return x*toMult.x + y*toMult.y;
	}
	double Length()
	{
		return sqrt(x*x+y*y);
	}

	T x, y;
};

typedef Vector2D<long> Vector;

int main()
{
#ifndef ONLINE_JUDGE
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif

	Vector vectors[MAX_VECTORS_COUNT];
	while(1)
	{
		long cVertices, iVertice;
		scanf("%ld", &cVertices);
		if(cVertices < 3) break;

		long xNew, yNew, xOld, yOld, xFirst, yFirst;
		long cVectors = 0;
		for(iVertice = 0; iVertice < cVertices; ++iVertice)
		{
			scanf("%ld %ld", &xNew, &yNew);
			if(iVertice != 0)
			{
				if(xOld != xNew || yOld != yNew)
				{
					vectors[cVectors++] = Vector(xNew-xOld, yNew-yOld);
				}
			}
			else
			{
				xFirst = xNew;
				yFirst = yNew;
			}
			xOld = xNew;
			yOld = yNew;
		}
		vectors[cVectors++] = Vector(xFirst-xOld, yFirst-yOld);
		vectors[cVectors++] = vectors[0];
		double angles[MAX_VECTORS_COUNT];
		double sumOfAngles = 0.0;
		for(long iVector = 0; iVector < cVectors-1; ++iVector)
		{
			long signOfAnlge = _sign(vectors[iVector]%vectors[iVector+1]);
			angles[iVector] = signOfAnlge*acos(
				vectors[iVector]*vectors[iVector+1] / 
				(vectors[iVector].Length()*vectors[iVector+1].Length()));
			sumOfAngles += angles[iVector];
		}
		double commonSign = sumOfAngles > 0 ? 1 : -1;
		double maxAngle = 0.0;
		double minAngle = 1e9;
		for(long iAngle = 0; iAngle < cVectors-1; ++iAngle)
		{
			if(maxAngle < PI - commonSign*angles[iAngle])
			{
				maxAngle = PI - commonSign*angles[iAngle];
			}
			if(minAngle > PI - commonSign*angles[iAngle])
			{
				minAngle = PI - commonSign*angles[iAngle];
			}
		}
		printf("%.6lf %.6lf\n", _ToDegrees(minAngle), _ToDegrees(maxAngle));
	}

#ifndef ONLINE_JUDGE
	fclose(stdin);
	fclose(stdout);
#endif
	return 0;
}